<?php

namespace Drupal\performance_budget\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\State\StateInterface;
use Drupal\web_page_archive\Entity\WebPageArchiveInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class AggregateBatchController.
 */
class HistoricalReportController extends ControllerBase {

  /**
   * Constructs a new AcheckerHistoryController.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(StateInterface $state) {
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state')
    );
  }

  /**
   * Displays the body for the historical report.
   *
   * @param \Drupal\web_page_archive\Entity\WebPageArchiveInterface $web_page_archive
   *   The web page archive config entity.
   *
   * @return array
   *   Render array for the historical report.
   */
  public function content(WebPageArchiveInterface $web_page_archive) {
    $queue_name = AggregateBatchController::getQueueName($web_page_archive);

    // If this is our first time viewing the report, go to the process form.
    $state_array = $this->state->get($queue_name);
    if (!isset($state_array)) {
      return $this->redirect('entity.web_page_archive.pb_wpt_history.process', ['web_page_archive' => $web_page_archive->id()]);
    }

    $ret = [
      '#theme' => 'pb-wpt-history',
      '#attached' => [
        'drupalSettings' => [
          'pbWptResults' => $state_array,
        ],
      ],
    ];

    // Look for custom chart.js options.
    $capture_config = $web_page_archive->getCaptureUtilities()->getConfiguration();
    foreach ($capture_config as $utility_config) {
      if ($utility_config['id'] == 'pb_wpt_capture' && !empty($utility_config['data']['chartjs_option'])) {
        $ret['#chartjs_option'] = $utility_config['data']['chartjs_option'];
        break;
      }
    }

    return $ret;
  }

  /**
   * Displays the title for the historical report.
   *
   * @param \Drupal\web_page_archive\Entity\WebPageArchiveInterface $web_page_archive
   *   The web page archive config entity.
   *
   * @return string
   *   Title of the historical report.
   */
  public function title(WebPageArchiveInterface $web_page_archive) {
    return $this->t('@job Historical Report', ['@job' => $web_page_archive->label()]);
  }

}
